==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/realm/entity/MapClientInitialAccessEntityFields.java <==
package org.keycloak.models.map.realm.entity;
public enum MapClientInitialAccessEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity e) {
            return (String) e.getId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity e, T value) {
            e.setId((String) value);
        }
    },
    COUNT {
        public static final String FIELD_NAME = "Count";
        public static final String FIELD_NAME_DASHED = "count";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Integer.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Integer get(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity e) {
            return (Integer) e.getCount();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity e, T value) {
            e.setCount((Integer) value);
        }
    },
    EXPIRATION {
        public static final String FIELD_NAME = "Expiration";
        public static final String FIELD_NAME_DASHED = "expiration";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Long.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Long get(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity e) {
            return (Long) e.getExpiration();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity e, T value) {
            e.setExpiration((Long) value);
        }
    },
    REMAINING_COUNT {
        public static final String FIELD_NAME = "RemainingCount";
        public static final String FIELD_NAME_DASHED = "remaining-count";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Integer.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Integer get(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity e) {
            return (Integer) e.getRemainingCount();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity e, T value) {
            e.setRemainingCount((Integer) value);
        }
    },
    TIMESTAMP {
        public static final String FIELD_NAME = "Timestamp";
        public static final String FIELD_NAME_DASHED = "timestamp";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Long.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Long get(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity e) {
            return (Long) e.getTimestamp();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity e, T value) {
            e.setTimestamp((Long) value);
        }
    },
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapClientInitialAccessEntityFields.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public enum MapClientInitialAccessEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        public static final String FIELD_NAME_CAMEL_CASE = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity e, T value) {
            e.setId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity e) {
            return (String) e.getId();
        }
    },
    COUNT {
        public static final String FIELD_NAME = "Count";
        public static final String FIELD_NAME_DASHED = "count";
        public static final String FIELD_NAME_CAMEL_CASE = "count";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Integer.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public Integer get(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity e) {
            return (Integer) e.getCount();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity e, T value) {
            e.setCount((Integer) value);
        }
    },
    EXPIRATION {
        public static final String FIELD_NAME = "Expiration";
        public static final String FIELD_NAME_DASHED = "expiration";
        public static final String FIELD_NAME_CAMEL_CASE = "expiration";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Long.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity e, T value) {
            e.setExpiration((Long) value);
        }
        @SuppressWarnings("unchecked") @Override public Long get(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity e) {
            return (Long) e.getExpiration();
        }
    },
    REMAINING_COUNT {
        public static final String FIELD_NAME = "RemainingCount";
        public static final String FIELD_NAME_DASHED = "remaining-count";
        public static final String FIELD_NAME_CAMEL_CASE = "remainingCount";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Integer.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity e, T value) {
            e.setRemainingCount((Integer) value);
        }
        @SuppressWarnings("unchecked") @Override public Integer get(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity e) {
            return (Integer) e.getRemainingCount();
        }
    },
    TIMESTAMP {
        public static final String FIELD_NAME = "Timestamp";
        public static final String FIELD_NAME_DASHED = "timestamp";
        public static final String FIELD_NAME_CAMEL_CASE = "timestamp";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Long.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity e, T value) {
            e.setTimestamp((Long) value);
        }
        @SuppressWarnings("unchecked") @Override public Long get(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity e) {
            return (Long) e.getTimestamp();
        }
    },
}
